@@ -7,10 +7,10 @@
 # http://opensource.org/licenses/MIT>, at your option. This file may not be
 # copied, modified, or distributed except according to those terms.
 
-import click
 import json
 import os
 
+import click
 import usb.core
 
 import solo
@@ -18,8 +18,8 @@ import solo.operations
 from solo.cli.key import key
 from solo.cli.monitor import monitor
 from solo.cli.program import program
-from . import _patches  # noqa  (since otherwise "unused")
 
+from . import _patches  # noqa  (since otherwise "unused")
 
 if (os.name == "posix") and os.environ.get("ALLOW_ROOT") is None:
     if os.geteuid() == 0:
@@ -100,9 +100,24 @@ solo_cli.add_command(sign)
 
 @click.command()
 @click.option("--attestation-key", help="attestation key in hex")
+@click.option("--attestation-cert", help="attestation certificate file")
+@click.option(
+    "--lock",
+    help="Indicate to lock device from unsigned changes permanently.",
+    default=False,
+    is_flag=True,
+)
 @click.argument("input_hex_files", nargs=-1)
 @click.argument("output_hex_file")
-def mergehex(attestation_key, input_hex_files, output_hex_file):
+@click.option(
+    "--end_page",
+    help="Set APPLICATION_END_PAGE. Should be in sync with firmware settings.",
+    default=20,
+    type=int,
+)
+def mergehex(
+    attestation_key, attestation_cert, lock, input_hex_files, output_hex_file, end_page
+):
     """Merges hex files, and patches in the attestation key.
 
     \b
@@ -110,7 +125,12 @@ def mergehex(attestation_key, input_hex_files, output_hex_file):
     Note that later hex files replace data of earlier ones, if they overlap.
     """
     solo.operations.mergehex(
-        input_hex_files, output_hex_file, attestation_key=attestation_key
+        input_hex_files,
+        output_hex_file,
+        attestation_key=attestation_key,
+        APPLICATION_END_PAGE=end_page,
+        attestation_cert=attestation_cert,
+        lock=lock,
     )
 
 
