@@ -14,6 +14,7 @@ import sys
 import tempfile
 import time
 
+import solo.exceptions
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from fido2.attestation import Attestation
@@ -24,8 +25,6 @@ from fido2.ctap2 import CTAP2
 from fido2.hid import CTAPHID, CtapHidDevice
 from fido2.utils import Timeout
 from intelhex import IntelHex
-
-import solo.exceptions
 from solo import helpers
 from solo.commands import SoloBootloader, SoloExtension
 
@@ -252,7 +251,7 @@ class SoloClient:
         except CtapError as e:
             if e.code == CtapError.ERR.INVALID_COMMAND:
                 print(
-                    "Solo appears to not be a solo hacker.  Try holding down the button for 2 while you plug token in."
+                    "Could not switch into bootloader mode.  Please hold down the button for 2s while you plug token in."
                 )
                 sys.exit(1)
             else:
