@@ -10,12 +10,11 @@
 import struct
 import time
 
+import solo.exceptions
+import usb._objfinalizer
 import usb.core
 import usb.util
-import usb._objfinalizer
-
 from solo.commands import DFU, STM32L4
-import solo.exceptions
 
 
 def find(dfu_serial=None, attempts=8, raw_device=None, altsetting=1):
@@ -148,9 +147,7 @@ class DFUDevice:
 
     def clear_status(self,):
         # bmReqType, bmReq, wValue, wIndex, data/size
-        _ = self.dev.ctrl_transfer(
-            DFU.type.SEND, DFU.bmReq.CLRSTATUS, 0, self.intNum, None
-        )
+        self.dev.ctrl_transfer(DFU.type.SEND, DFU.bmReq.CLRSTATUS, 0, self.intNum, None)
 
     def upload(self, block, size):
         """
